@@ -35,7 +35,8 @@
 #' Default is to have a constant node size throughout. 'leafCount' can also
 #' be used here (cumulative count of a node's children), or 'count'
 #' (count of node's immediate children).
-#' @param collapsed the tree's children will start collapsed by default
+#' @param collapsed the tree's children will start collapsed by default.
+#' Can also be a logical value found in the data for conditionally collapsing nodes.
 #' @param zoomable pan and zoom by dragging and scrolling
 #' @param width width in pixels (optional, defaults to automatic sizing)
 #' @param height height in pixels (optional, defaults to automatic sizing)
@@ -110,6 +111,7 @@ collapsibleTreeNetwork <- function(df, inputId = NULL, attribute = "leafCount",
   if(sum(is.na(df[,1])) != 1) stop("there must be 1 NA for root in the first column")
   if(!is.character(fill)) stop("fill must be a either a color or column name")
   if(!(attribute %in% c(colnames(df), nodeAttr))) stop("attribute column name is incorrect")
+  if(is.character(collapsed) & !(collapsed %in% c(colnames(df), nodeAttr))) stop("collapsed column name is incorrect")
   if(!is.null(tooltipHtml)) if(!(tooltipHtml %in% colnames(df))) stop("tooltipHtml column name is incorrect")
   if(!is.null(nodeSize)) if(!(nodeSize %in% c(colnames(df), nodeAttr))) stop("nodeSize column name is incorrect")
 
@@ -195,14 +197,20 @@ collapsibleTreeNetwork <- function(df, inputId = NULL, attribute = "leafCount",
     jsonFields <- c(jsonFields, "tooltip")
   }
 
+  # if collapsed is specified, pass it on in the data
+  if(is.character(collapsed)) jsonFields <- c(jsonFields, collapsed)
+
   # only necessary to perform these calculations if there is a nodeSize specified
   if(!is.null(nodeSize)) {
     # Scale factor to keep the median leaf size around 10
     scaleFactor <- 10/data.tree::Aggregate(node, nodeSize, stats::median)
     # traverse down the tree and compute the weights of each node for the tooltip
     t <- data.tree::Traverse(node, "pre-order")
+    # can't use substitute inside a subfunction
+    aggFunIsIdentity <- substitute(aggFun)=="identity"
     data.tree::Do(t, function(x) {
-      x$SizeOfNode <- data.tree::Aggregate(x, nodeSize, sum)
+      if (aggFunIsIdentity) x$SizeOfNode <- x[[nodeSize]]
+      else x$SizeOfNode <- data.tree::Aggregate(x, nodeSize, sum)
       # scale node growth to area rather than radius and round
       x$SizeOfNode <- round(sqrt(x$SizeOfNode*scaleFactor)*pi, 2)
     })
